==> haskell-doctest-exitcode-stdio-0.0-144-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-exitcode-stdio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-exitcode-stdio
version:              0.0
visibility:           public
id:                   doctest-exitcode-stdio-0.0-3KBbLqyGxq4KkdebAO3Zet
key:                  doctest-exitcode-stdio-0.0-3KBbLqyGxq4KkdebAO3Zet
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             https://hub.darcs.net/thielema/doctest-exitcode-stdio/
synopsis:             Run doctest'\''s in a Cabal.Test.exitcode-stdio environment
description:
    Run doctest'\''s in a Cabal.Test.exitcode-stdio environment.
    For use with the @doctest-extract@ utility.
    Normally, you should not need to import a module from this package,
    only generated code will do this.

category:             Testing
abi:                  f5318053d1c994dc4ad0b3262434cc0f
exposed:              True
exposed-modules:      Test.DocTest.Driver
import-dirs:          /usr/lib/ghc-9.2.8/site-local/doctest-exitcode-stdio-0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/doctest-exitcode-stdio-0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-exitcode-stdio
hs-libraries:         HSdoctest-exitcode-stdio-0.0-3KBbLqyGxq4KkdebAO3Zet
depends:
    QuickCheck-2.14.3-5Q3LTiKAdB0LFKfPwDt7Ga base-4.16.4.0
    doctest-lib-0.1.1.1-JOCXoj4nLevAcQktoJxInB transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-doctest-exitcode-stdio/html/doctest-exitcode-stdio.haddock

haddock-html:         /usr/share/doc/haskell-doctest-exitcode-stdio/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-exitcode-stdio-0.0-145-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-exitcode-stdio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-exitcode-stdio
version:              0.0
visibility:           public
id:                   doctest-exitcode-stdio-0.0-BsVYW9MA1YsGiNXRKjqodD
key:                  doctest-exitcode-stdio-0.0-BsVYW9MA1YsGiNXRKjqodD
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             https://hub.darcs.net/thielema/doctest-exitcode-stdio/
synopsis:             Run doctest'\''s in a Cabal.Test.exitcode-stdio environment
description:
    Run doctest'\''s in a Cabal.Test.exitcode-stdio environment.
    For use with the @doctest-extract@ utility.
    Normally, you should not need to import a module from this package,
    only generated code will do this.

category:             Testing
abi:                  bcfbb73a6e993f8ff380a3c8a5633128
exposed:              True
exposed-modules:      Test.DocTest.Driver
import-dirs:          /usr/lib/ghc-9.2.8/site-local/doctest-exitcode-stdio-0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/doctest-exitcode-stdio-0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-exitcode-stdio
hs-libraries:         HSdoctest-exitcode-stdio-0.0-BsVYW9MA1YsGiNXRKjqodD
depends:
    QuickCheck-2.14.3-J0ejVxF0pWfG4YkvYql6Th base-4.16.4.0
    doctest-lib-0.1.1.1-JOCXoj4nLevAcQktoJxInB transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-doctest-exitcode-stdio/html/doctest-exitcode-stdio.haddock

haddock-html:         /usr/share/doc/haskell-doctest-exitcode-stdio/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
